@@ -351,16 +351,16 @@ def build2(javaEnv,dirs):
     local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
 
-#   local('mkdir -p deploy/worker/config')
-#    local('mkdir -p deploy/worker/lib')
+    local('mkdir -p deploy/worker/config')
+    local('mkdir -p deploy/worker/lib')
 
-#    local('cp config/keyset-prod.json deploy/worker/config/keyset.json')
-#    local('cp config/logback.xml deploy/worker/config/')
-#    local('cp config/application-prod-worker.yml deploy/worker/config/')
+    local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
+    local('cp config/logback.xml deploy/worker/config/')
+    local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
 
-#    local('cp -r worker/target/lib/ deploy/worker/')
+    local('cp -r worker/target/lib/ deploy/worker/')
 
-#    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
+    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
 
 
 
